# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'Metric',
    'MetricsGranularity',
    'NotificationType',
]


class Metric(str, Enum):
    """
    See https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_EnableMetricsCollection.html
    """
    GROUP_MIN_SIZE = "GroupMinSize"
    GROUP_MAX_SIZE = "GroupMaxSize"
    GROUP_DESIRED_CAPACITY = "GroupDesiredCapacity"
    GROUP_IN_SERVICE_INSTANCES = "GroupInServiceInstances"
    GROUP_IN_SERVICE_CAPACITY = "GroupInServiceCapacity"
    GROUP_PENDING_INSTANCES = "GroupPendingInstances"
    GROUP_PENDING_CAPACITY = "GroupPendingCapacity"
    GROUP_STANDBY_INSTANCES = "GroupStandbyInstances"
    GROUP_STANDBY_CAPACITY = "GroupStandbyCapacity"
    GROUP_TERMINATING_INSTANCES = "GroupTerminatingInstances"
    GROUP_TERMINATING_CAPACITY = "GroupTerminatingCapacity"
    GROUP_TOTAL_INSTANCES = "GroupTotalInstances"
    GROUP_TOTAL_CAPACITY = "GroupTotalCapacity"


class MetricsGranularity(str, Enum):
    """
    See https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_EnableMetricsCollection.html
    """
    ONE_MINUTE = "1Minute"


class NotificationType(str, Enum):
    """
    See https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_NotificationConfiguration.html
    """
    INSTANCE_LAUNCH = "autoscaling:EC2_INSTANCE_LAUNCH"
    INSTANCE_TERMINATE = "autoscaling:EC2_INSTANCE_TERMINATE"
    INSTANCE_LAUNCH_ERROR = "autoscaling:EC2_INSTANCE_LAUNCH_ERROR"
    INSTANCE_TERMINATE_ERROR = "autoscaling:EC2_INSTANCE_TERMINATE_ERROR"
    TEST_NOTIFICATION = "autoscaling:TEST_NOTIFICATION"
